==> scribo_0.2.10-789.tar.gz: scribo-0.2.10/src/test/Debug.py <==
#!/usr/bin/env python

"""
===============================================================
    File for debugging all application
===============================================================
"""

__author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
__version__ = "$Revision: 21 $"
__date__ = "$Date: 2010/02/06 $"
__copyright__ = ""
__license__ = "GPLv2"

import sys
sys.path.append("..")
sys.path.append("../ldm")
sys.path.append("../services")

from LivejAccount import LivejAccount
from BlurtyAccount import BlurtyAccount
from Message import Message
from Profile import Profile
from SqlDriver import sql_driver

def cback():
    print "Updated..."

def test():
    """
    this is test function
    """

    acc = LivejAccount()


    #acc1.username = "maemoblogs"
    #acc.passwd = "maemo100500"
    acc.username = "scribo-rpc"
    acc.passwd = "test123"
    #acc.date = None#"0000-00-00 00:00:00"#"2009-08-21 13:27:00" 
    #acc.check_login()
    #acc.refresh_posts(cback)

    #msg = Message(1)
    #m = msg.copy()
    #msg = Message(7)
    #acc.edit_post(msg)

    #acc.remove_friend(acc1)
    #acc.add_comment()

    #acc.test()
    acc._get_avatar('http://l-userpic.livejournal.com/9277267/484155')
    #acc.refresh_friends_list()

    acc.refresh_friends_page(cback)
    #acc.refresh_posts(cback)



    #del(sql_driver)
    return None

def get_uname(acc):
    uname = acc.username


def test2():

    from LivejAccount import LivejAccount
    from Profile import main_prof


    i = 0
    while True:
        i += 1
        p = main_prof.get_posts()
        #get_uname(acc)
        #uname = acc.username
        print i, ' ', len(p)

def test_copy():
    m = Message()
    m.text = 1
    m.title = 2
    m.tags = 3

    mm = m.copy()

    a = LivejAccount()
    a.username = '1'
    a.passwd = '2'

    aa = a.copy()

    p = Profile()
    p.add_account(a)
    p.def_account = a

    pp = p.copy()

    pass

def config_test():

    from ConfigDriver import config

    c = config.get_bool('UI', 'warning_press_refresh')
    cc = config.get_bool('UI', 'autorefresh')
    pass

if __name__ == "__main__":
    test()

    sql_driver.close()

==> scribo_0.2.20-850.tar.gz: scribo-0.2.20/src/test/Debug.py <==
#!/usr/bin/env python

"""
===============================================================
    File for debugging all application
===============================================================
"""

__author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
__version__ = "$Revision: 21 $"
__date__ = "$Date: 2010/02/06 $"
__copyright__ = ""
__license__ = "GPLv2"

import sys

from services.LivejAccount import LivejAccount
from services.BlurtyAccount import BlurtyAccount
from ldm.Message import Message
from ldm.Profile import main_prof
from ldm.SqlDriver import sql_driver

def cback():
    print "Updated..."

def test():
    """
    this is test function
    """

    acc = LivejAccount()
    #acc1 = LivejAccount()

    #acc1.username = "maemoblogs"
    #acc1.passwd = "maemo100500"
    #acc1.refresh_posts(cback)

    acc.username = "scribo-rpc"
    acc.passwd = "test123"
    #acc.date = None#"0000-00-00 00:00:00"#"2009-08-21 13:27:00" 
    #acc.check_login()


    #msg = Message(1)
    #m = msg.copy()
    #msg = Message(7)
    #acc.edit_post(msg)

    #acc.remove_friend(acc1)
    #acc.add_comment()

    #acc.test()
    #acc._get_avatar('http://l-userpic.livejournal.com/9277267/484155')
    #acc.refresh_friends_list()


    try:
        main_prof.add_account(acc)
    except:
        pass
    else:
        acc.refresh_friends_page(cback)
    list = main_prof.get_friends_posts(1)
    #acc.refresh_posts(cback)



    #del(sql_driver)
    return None

def get_uname(acc):
    uname = acc.username


def test2():

    from LivejAccount import LivejAccount
    from Profile import main_prof


    i = 0
    while True:
        i += 1
        p = main_prof.get_posts()
        #get_uname(acc)
        #uname = acc.username
        print i, ' ', len(p)

def test_copy():
    m = Message()
    m.text = 1
    m.title = 2
    m.tags = 3

    mm = m.copy()

    a = LivejAccount()
    a.username = '1'
    a.passwd = '2'

    aa = a.copy()

    p = Profile()
    p.add_account(a)
    p.def_account = a

    pp = p.copy()

    pass

def config_test():

    from ConfigDriver import config

    c = config.get_bool('UI', 'warning_press_refresh')
    cc = config.get_bool('UI', 'autorefresh')
    pass

if __name__ == "__main__":
    test()

    sql_driver.close()
